/*
	manifold  -  disperse  contents  of a file to one or more others.
	Copyright (C) 2002 R.L. Horn

	This program is free software; you  can  redistribute  it  and/or
	modify  it  under  the terms of the GNU General Public License as
	published by the Free Software Foundation; either  version  2  of
	the License, or (at your option) any later version.

	This  program  is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the  implied  warranty  of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to:

		The Free Software Foundation, Inc.
		59 Temple Place, Suite 330
		Boston, MA  02111-1307
		USA
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#if USE_TERMINFO

#include <stdio.h>

#if HAVE_NCURSES_H
#  include <ncurses.h>
#elif HAVE_NCURSES_NCURSES_H
#  include <ncurses/ncurses.h>
#else
#  include <curses.h>
#endif

#if HAVE_NCURSES_TERM_H
#  include <ncurses/term.h>
#else
#  include <term.h>
#endif

#include "dterm.h"

#define NORMAL 0
#define UNDERLINE 1
#define BOLD 2

static char *enter_standout, *exit_standout,
			*enter_underline, *exit_underline,
			*enter_dim,
			*enter_bold,
			*enter_reverse,
			*exit_attributes;

static void
setmode(int *curmode, int newmode)
{
	if ( (*curmode != NORMAL) && (newmode != NORMAL) )
		setmode(curmode,NORMAL);

	switch (newmode) {
		case NORMAL:
			switch(*curmode) {
				case NORMAL:
					break;
				case UNDERLINE:
					putp(exit_underline);
					break;
				default:
					/* This includes standout */
					putp(exit_attributes);
					break;
		}
		break;
		case UNDERLINE:
			putp(enter_underline);
			break;
		case BOLD:
			putp(enter_bold);
			break;
		default:
			/*
			 * We should have some provision here for multiple modes
			 * on at once.  This will have to come later.
			*/
			putp(enter_standout);
			break;
	}
	*curmode = newmode;
}
                    
int
dterm_print(char *term, const char *s)
{
	const char *p = s;
	char c;
	int escape = 0, curmode = NORMAL, errret;

	if (ERR == setupterm(term,fileno(stdout),&errret))
		/* fail silently */
		return 1;

	def_shell_mode();

	enter_standout = tigetstr("smso");
	exit_standout = tigetstr("rmso");
	enter_underline = tigetstr("smul");
	exit_underline = tigetstr("rmul");
	enter_dim = tigetstr("dim");
	enter_bold = tigetstr("bold");
	enter_reverse = tigetstr("rev");
	exit_attributes = tigetstr("sgr0");

	if (!enter_bold && enter_reverse)
		enter_bold = enter_reverse;
	if (!enter_bold && enter_standout)
		enter_bold = enter_standout;
	if (!enter_underline && enter_standout) {
		enter_underline = enter_standout;
		exit_underline = exit_standout;
	}
	if (!enter_dim && enter_standout)
		enter_dim = enter_standout;
	if (!enter_reverse && enter_standout)
		enter_reverse = enter_standout;
	if (!exit_attributes && exit_standout)
		exit_attributes = exit_standout;

	while ((c = *p++)) {
		if (escape) {
			escape = 0;
			switch (c) {
				case 'B':
					setmode(&curmode, curmode^BOLD);
					break;
				case 'U':
					setmode(&curmode, curmode^UNDERLINE);
					break;
				default:
					putchar('\\');
					putchar(c);
					break;
			}
		} else {
			escape = (c == '\\');
			if (!escape) putchar(c);
		}
	}

	reset_shell_mode();
	return 0;
}

#endif
