/*
	manifold  -  disperse  contents  of a file to one or more others.
	Copyright (C) 2002 R.L. Horn

	This program is free software; you  can  redistribute  it  and/or
	modify  it  under  the terms of the GNU General Public License as
	published by the Free Software Foundation; either  version  2  of
	the License, or (at your option) any later version.

	This  program  is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the  implied  warranty  of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to:

		The Free Software Foundation, Inc.
		59 Temple Place, Suite 330
		Boston, MA  02111-1307
		USA
*/

#if HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>

#include "usage.h"
#include "dsprsdef.h"
#include "optstr.h"

extern char *pgmname;
extern int tee;

void
usage(FILE *f)
{
	if (tee) {
		fprintf(f,
			"Usage: tee [OPTION ...] [OUT_FILE ...]\n"
			"Copy standard input to each OUT_FILE, and also to standard output.\n"
		);
	} else {
		fprintf(f,
			"Usage: %s [OPTION ...] IN_FILE [OUT_FILE ...]\n"
			"Disperse contents of IN_FILE to one or more OUT_FILEs.\n"
			,pgmname);
	}

	fprintf(f,
		"\n"
		OPT_STR_APPEND "Append all files.\n"
		OPT_STR_IGNORE "Ignore interrupt signal.\n"
		OPT_STR_LINEBUFFER "Output files are line buffered.\n"
		OPT_STR_HEADER "Write header.\n"
		OPT_STR_HEADER_STRING "Specify header string (implies -h).\n"
		OPT_STR_FOOTER "Write footer.\n"
		OPT_STR_FOOTER_STRING "Specify footer string (implies -f).\n"
		OPT_STR_UTC "Use UTC rather than local time in headers/footers.\n"
		OPT_STR_NONPRINTING "Use  octal backslash notation for nonprinting characters.\n"
#if HAVE_NCURSES_TERM_H || HAVE_TERM_H
		OPT_STR_TERMINFO "Use  terminfo data to display bold and underlined text in\n"
		"             headers/footers on stdout\n"
		OPT_STR_TERMINAL "Like -t, but force terminal `term'.\n"
#endif
		OPT_STR_QUIET "Don't report errors.\n"
		"  -V, --version\n"
		"             Display version number and exit.\n"
		"  --help     Display help and exit.\n"
		"\n"
		"If no  OUT_FILE  is specified,  OUT_FILE is `-',  or OUT_FILE is `&1',\n"
		"write to standard output.  If OUT_FILE is `&2',  write to standard er-\n"
		"ror (implies -q).\n"
		"\n"
		"If  OUT_FILE is prepended by `>>' and the -a option is  NOT  specified\n"
		"OUT_FILE  will be appended to rather than rewritten.   If -a is speci-\n"
		"fied  this has no effect and the `>>' characters are NOT stripped from\n"
		"the file name.\n"
		"\n"
#if HAVE_LIBZ
		"Output files with names ending in `.gz' will be compressed  (deflated)\n"
		"on the fly.\n"
		"\n"
#endif
		"Headers and footers are processed using strftime(3) to allow for time-\n"
		"stamping.  In addition, the following escape sequences are recognized:\n"
		"\n"
		"  \\a     bell\n"
		"  \\b     backspace\n"
		"  \\e     escape character\n"
		"  \\f     formfeed\n"
		"  \\n     newline\n"
		"  \\r     carriage return\n"
		"  \\t     horizontal tab\n"
		"  \\v     vertical tab\n"
		"  \\\\     `\\'\n"
		"  \\B     toggle bold\n"
		"  \\U     toggle underscore\n"
#if HAVE_UNAME
		"  \\M     machine type (uname -m)\n"
#endif
#if (HAVE_UNAME || HAVE_GETHOSTNAME)
		"  \\N     network node hostname (uname -n)\n"
#endif
#if HAVE_UNAME
		"  \\R     operating system release (uname -r)\n"
		"  \\S     operating system name (uname -s)\n"
		"  \\V     current   version  level  within  operating  system  release\n"
		"         (uname -v)\n"
#endif
		"\n"
		"The default values are:\n"
		"\n"
		"    Header: `%s'\n"
		"    Footer: `%s'\n"
		,DEFAULT_HEADER,DEFAULT_FOOTER
	);
}

void
version(void)
{
	puts(VERSION);
}
